//------------------------------------------------------------------------------
// Digitally controlled 2.1 channel power amplifier system.
// PIC18F452 (IC1) firmware.
// Dilshan R Jayakody <jayakody2000lk@gmail.com>
//
// This Source Code Form is subject to the terms of the
// Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
// with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
//------------------------------------------------------------------------------

#define _SUBAMP452__

#define TRUE 0xFF
#define FALSE 0x00

#define MAX_LCD_COLUMN_COUNT 15
#define MAX_VOLUME_LIMIT 0x3F
#define TIMEOUT_LIMIT 0x300

#define DEFAULT_VOLUME 0x3F
#define DEFAULT_BASS 0x07
#define DEFAULT_TRIBBLE 0x07
#define DEFAULT_LOUDNESS 0x00
#define DEFAULT_BALANCE 0x01
#define DEFAULT_BASS_ADD 0x00
#define DEFAULT_BASE_GAIN 0x00

// define 1602 LCD I/O interface.
sbit LCD_RS at RD0_bit;
sbit LCD_EN at RD1_bit;
sbit LCD_D4 at RD2_bit;
sbit LCD_D5 at RD3_bit;
sbit LCD_D6 at RD4_bit;
sbit LCD_D7 at RD5_bit;

sbit LCD_RS_Direction at TRISD0_bit;
sbit LCD_EN_Direction at TRISD1_bit;
sbit LCD_D4_Direction at TRISD2_bit;
sbit LCD_D5_Direction at TRISD3_bit;
sbit LCD_D6_Direction at TRISD4_bit;
sbit LCD_D7_Direction at TRISD5_bit;

void reset_system();
void init_system();
void recall_system();

void draw_homescreen();
void draw_setupscreen();
void draw_system_volume();

void lcd_clear_row(char row);
void update_mute_state(unsigned char is_mute);
void lcd_print_value(char row, char col, unsigned char value);
void update_tone_control(unsigned char tone_command);
void update_bass_processor(unsigned char bass_command);